@@ -1,4 +1,3 @@
-"""python -m powrap entry point.
-"""
+"""python -m powrap entry point."""
 
 __import__("powrap.powrap").powrap.main()
